AnonymousPlugin<TContext> class final

Anonymous authenticated identities that can later be linked to a real sign-in method by the host integration.

Implemented types

Constructors

AnonymousPlugin({AuthAnonymousNameGenerator<TContext>? generateName, bool disableDeleteAnonymousUser = false})

Properties

clientOperations Iterable<AuthClientOperationDescriptor>
no setteroverride
disableDeleteAnonymousUser bool
final
endpoints Iterable<AuthEndpointDescriptor<TContext>>
no setteroverride
generateName AuthAnonymousNameGenerator<TContext>?
final
hashCode int
The hash code for this object.
no setterinherited
id String
no setteroverride
persistenceSchemas Iterable<AuthPersistenceSchema>
no setteroverride
rateLimitOperations Iterable<AuthRateLimitOperation>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userDataNamespace String
no setteroverride

Methods

completeAnonymousAccountUpgrade({required AuthUser anonymousUser, required AuthUser targetUser}) Future<void>
Finalizes an upgrade after the host has issued the target user's session.
configure(AuthServerPluginContext<TContext> context) → void
override
createUserDeletionPlan(AuthUser user) AuthUserDeletionPlan
override
deleteAnonymousUser({required AuthUser user}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signInAnonymous({required TContext context}) Future<AuthAnonymousSignInResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited