persistenceSchemas property
Implementation
@override
Iterable<AuthPersistenceSchema> get persistenceSchemas => const [
AuthPersistenceSchema(
id: authAnonymousPluginId,
entities: <AuthEntityDescriptor>[
AuthEntityDescriptor(
id: 'user',
fields: <AuthFieldDescriptor>[
AuthFieldDescriptor(name: 'isAnonymous', kind: 'boolean'),
],
),
],
atomicOperations: <AuthAtomicOperationDescriptor>[
AuthAtomicOperationDescriptor(
id: 'anonymous.createAccount',
description:
'Create one anonymous identity and its replay receipt in a backend transaction.',
),
AuthAtomicOperationDescriptor(
id: 'anonymous.deleteUser',
description:
'Delete the anonymous user through the backend-owned deletion transaction.',
),
AuthAtomicOperationDescriptor(
id: 'anonymous.completeUpgrade',
description:
'Delete an upgraded anonymous identity and record replay completion atomically after host-owned session issuance.',
),
],
),
];