AuthAdminHooks<TContext> class final

Constructors

AuthAdminHooks({AuthAdminBeforeHook<TContext, Object>? beforeUser, AuthAdminAfterHook<TContext, Object>? afterUser, AuthAdminBeforeHook<TContext, Object>? beforeRole, AuthAdminAfterHook<TContext, Object>? afterRole, AuthAdminBeforeHook<TContext, Object>? beforeBan, AuthAdminAfterHook<TContext, Object>? afterBan, AuthAdminAfterHook<TContext, Object>? afterSession, AuthAdminBeforeHook<TContext, Object>? beforeDelete, AuthAdminAfterHook<TContext, Object>? afterDelete, AuthAdminBeforeHook<TContext, Object>? beforeImpersonation, AuthAdminAfterHook<TContext, Object>? afterImpersonation})
const

Properties

afterBan AuthAdminAfterHook<TContext, Object>?
final
afterDelete AuthAdminAfterHook<TContext, Object>?
final
afterImpersonation AuthAdminAfterHook<TContext, Object>?
final
afterRole AuthAdminAfterHook<TContext, Object>?
final
afterSession AuthAdminAfterHook<TContext, Object>?
final
afterUser AuthAdminAfterHook<TContext, Object>?
final
beforeBan AuthAdminBeforeHook<TContext, Object>?
final
beforeDelete AuthAdminBeforeHook<TContext, Object>?
final
beforeImpersonation AuthAdminBeforeHook<TContext, Object>?
final
beforeRole AuthAdminBeforeHook<TContext, Object>?
final
beforeUser AuthAdminBeforeHook<TContext, Object>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited