AuthAdminImpersonationStartDecision class final

Authentication data for auth admin impersonation start decision.

Constructors

AuthAdminImpersonationStartDecision({required AuthUser actor, required AuthAdminUser target})
Creates an instance of AuthAdminImpersonationStartDecision.
const

Properties

actor AuthUser
The user performing this operation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target AuthAdminUser
The user or resource targeted by this operation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited