AuthAdminInternalFailure class final

Failure details for auth admin internal failure.

Constructors

AuthAdminInternalFailure({required String operation, required Object error, required StackTrace stackTrace, required String targetUserId})
Creates an instance of AuthAdminInternalFailure.
const

Properties

error Object
The error associated with this value.
final
hashCode int
The hash code for this object.
no setterinherited
operation String
The operation associated with this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
The stack trace captured for the failure.
final
targetUserId String
The identifier of target user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited