AuthAdminMutation<T> class
sealed
A typed mutation executed entirely by an AuthAdminStore.
- Implementers
- AuthAdminCreateUserMutation
- AuthAdminDeleteUserMutation
- AuthAdminPrepareImpersonationMutation
- AuthAdminPrepareStopImpersonatingMutation
- AuthAdminReplaceRolesMutation
- AuthAdminRevokeSessionMutation
- AuthAdminRevokeSessionsMutation
- AuthAdminSetAccountStateMutation
- AuthAdminSetBanMutation
- AuthAdminSetPasswordMutation
- AuthAdminTrustedReplaceRolesMutation
- AuthAdminUpdateUserMutation
Properties
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited