AuthAdminRevokeSessionMutation class final

Mutation describing auth admin revoke session mutation.

Inheritance

Constructors

AuthAdminRevokeSessionMutation({required AuthAdminMutationAuthorization? authorization, required String userId, required String sessionId})
Creates an instance of AuthAdminRevokeSessionMutation.
const

Properties

authorization AuthAdminMutationAuthorization?
The authorization associated with this value.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
The identifier of the session.
final
userId String
The identifier of the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited