AuthAdminWarning class final

Authentication data for auth admin warning.

Constructors

AuthAdminWarning({required String code, String? message})
Creates an instance of AuthAdminWarning.
const
AuthAdminWarning.fromJson(Map<String, dynamic> json)
Creates an instance from a JSON map.
factory

Properties

code String
The code associated with this value.
final
hashCode int
The hash code for this object.
no setterinherited
message String?
The message associated with this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this value to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited