AuthAnonymousClient class final
Client for creating and deleting anonymous accounts.
Constructors
- AuthAnonymousClient(AuthClientCore _core)
- Creates an anonymous-account client backed by the shared client transport.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteUser(
) → Future< void> - Deletes the current anonymous account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signIn(
) → Future< AuthSession> - Creates an anonymous account and signs it in.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited