AuthApiKeyIssued class final

The only response that contains a raw API key.

Constructors

AuthApiKeyIssued({required AuthApiKey apiKey, required String key})
Creates the one-time response containing key.
const

Properties

apiKey AuthApiKey
Safe metadata for the issued key.
final
hashCode int
The hash code for this object.
no setterinherited
key String
Raw key shown to the caller once at issue or rotation time.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the metadata and one-time raw key.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited