AuthApiKeyPrimaryRevocationCommand class final

Complete input to an exact primary API-key revocation transaction.

Constructors

AuthApiKeyPrimaryRevocationCommand({required String userId, required String keyId, required DateTime revokedAt, required AuthAuthenticationMethodInventoryLoader loadInventory})

Properties

hashCode int
The hash code for this object.
no setterinherited
keyId String
final
loadInventory AuthAuthenticationMethodInventoryLoader
Loads the bounded composed topology as evidence for the backend command.
final
revokedAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited