revokeForUser abstract method
Revokes a key only when it belongs to userId.
Implementation
FutureOr<AuthApiKeyRecord?> revokeForUser(
String userId,
String id, {
DateTime? revokedAt,
});
Revokes a key only when it belongs to userId.
FutureOr<AuthApiKeyRecord?> revokeForUser(
String userId,
String id, {
DateTime? revokedAt,
});