AuthAuthenticationLifecycleContributor<TContext> class abstract interface

Optional plugin contributor notified only after host-owned lifecycle work has completed.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAuthenticationLifecycleEvent(AuthAuthenticationLifecycleEvent<TContext> event) FutureOr<void>
Handles a completed authentication lifecycle transition.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited