AuthAuthenticationLifecycleEvent<TContext> class final

Typed, in-memory host lifecycle event for optional authentication plugins.

The event is intentionally not serializable. authenticationMethod is a host-owned stable method label, never a credential, token, identifier, or provider response. OAuth hosts may additionally provide the bounded provider namespace in oauthProviderNamespace.

Constructors

AuthAuthenticationLifecycleEvent({required AuthAuthenticationLifecycleEventType type, required TContext context, required AuthSessionStrategy strategy, String? authenticationMethod, String? oauthProviderNamespace})
const

Properties

authenticationMethod String?
final
context → TContext
final
hashCode int
The hash code for this object.
no setterinherited
oauthProviderNamespace String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strategy AuthSessionStrategy
final
type AuthAuthenticationLifecycleEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited