AuthClientAuthResult class

The result of an auth callback that may return a session or redirect.

Constructors

AuthClientAuthResult({AuthSession? session, Uri? redirectUrl, String? status, String? email})
Creates the result of an auth callback.
const

Properties

email String?
Email associated with the callback, when returned by the server.
final
hashCode int
The hash code for this object.
no setterinherited
redirectUrl Uri?
Redirect returned by the callback, if the host requires navigation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session AuthSession?
Session returned directly by the callback, if any.
final
status String?
Provider-specific status returned without a session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited