AuthClientPlugin<TApi extends Object> class abstract interface

A typed, opt-in client API.

A plugin should expose only the operations owned by one server plugin or provider. Applications install the client plugins they use instead of receiving every optional auth operation on one client object.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable identifier used to install and retrieve this plugin.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

install(AuthClientPluginContext context) → TApi
Builds the typed API exposed by this plugin.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited