AuthClientResponse class final
Raw successful response returned by AuthClientTransport.
Constructors
- AuthClientResponse(int statusCode, Response response)
-
Creates a raw HTTP response wrapper.
const
Properties
- body → String
-
Response body text.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Response headers.
no setter
- response → Response
-
Original response from the HTTP client.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited