AuthCredentialsClient class final

Client for registering and signing in with credentials.

Constructors

AuthCredentialsClient(AuthClientCore _core, {String provider = 'credentials'})
Creates a credentials client for provider.

Properties

hashCode int
The hash code for this object.
no setterinherited
provider String
Provider identifier used for credential requests.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register({required String password, String? email, String? username, Map<String, dynamic>? attributes}) Future<AuthSession>
Registers a user with an email address or username and password.
signIn({required String password, String? email, String? username, Map<String, dynamic>? attributes}) Future<AuthSession>
Signs in with an email address or username and password.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited