AuthDeviceAuthorizationIssuanceLeaseStatus enum

Outcome of trying to acquire the bounded token-issuance lease.

Inheritance
  • Object
  • Enum
  • AuthDeviceAuthorizationIssuanceLeaseStatus
Available extensions

Values

acquired → const AuthDeviceAuthorizationIssuanceLeaseStatus

A lease was acquired by the caller.

busy → const AuthDeviceAuthorizationIssuanceLeaseStatus

Another unexpired lease currently owns the request.

invalid → const AuthDeviceAuthorizationIssuanceLeaseStatus

The request, client binding, or lease inputs are not valid.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthDeviceAuthorizationIssuanceLeaseStatus>
A constant List of the values in this enum, in order of their declaration.