AuthDurableSamlReplayStore class abstract interface

Marker implemented only by adapters with durable transactional guarantees.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

consumeIdpInitiated({required String providerId, required String assertionId, required DateTime assertionExpiresAt, required DateTime now}) FutureOr<bool>
Atomically records an IdP-initiated assertion ID exactly once.
inherited
consumeSpInitiated({required String providerId, required String requestId, required String relayStateHash, required String browserBindingHash, required String assertionId, required DateTime assertionExpiresAt, required DateTime now}) FutureOr<AuthSamlConsumptionResult>
Atomically consumes one request/RelayState tuple and records assertion ID.
inherited
createAttempt(AuthSamlAuthenticationAttempt attempt) FutureOr<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited