AuthEmailVerificationPayload class

Prepared payload for email verification sign-in flows.

Constructors

AuthEmailVerificationPayload({required String token, required DateTime expiresAt, required AuthMagicLinkRecord record, required AuthEmailRequest request, required AuthResult pendingResult})
const

Properties

expiresAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
pendingResult AuthResult
final
record AuthMagicLinkRecord
final
request AuthEmailRequest
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited