AuthEndpointPublicErrorKind enum

Host-level failure that happened outside a plugin handler.

Inheritance
Available extensions

Values

invalidRequest → const AuthEndpointPublicErrorKind

The request could not be decoded or validated.

internalFailure → const AuthEndpointPublicErrorKind

The host failed while handling an otherwise valid request.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthEndpointPublicErrorKind>
A constant List of the values in this enum, in order of their declaration.