AuthGateEvaluationContext<TContext> class

Context provided during gate evaluation.

Constructors

AuthGateEvaluationContext({required TContext context, required AuthPrincipal? principal, Object? payload})
Creates the callback input for a gate evaluation.

Properties

context → TContext
Framework/runtime context.
final
hashCode int
The hash code for this object.
no setterinherited
payload Object?
Optional payload for the evaluation.
final
principal AuthPrincipal?
The authenticated principal, if available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited