AuthJwtCallbackContext<TContext> class
Context passed to JWT callbacks.
Constructors
-
AuthJwtCallbackContext({required TContext context, required Map<
String, dynamic> token, required AuthUser user, required AuthSessionStrategy strategy, AuthProvider? provider, AuthAccount? account, Map<String, dynamic> ? profile, bool isNewUser = false})
Properties
- account → AuthAccount?
-
final
- context → TContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNewUser → bool
-
final
-
profile
→ Map<
String, dynamic> ? -
final
- provider → AuthProvider?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strategy → AuthSessionStrategy
-
final
-
token
→ Map<
String, dynamic> -
final
- user → AuthUser
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited