AuthMutationPersistence class final

Typed persistence semantics for a state-changing auth operation.

Constructors

AuthMutationPersistence.boundedEphemeral()
Creates bounded-ephemeral persistence semantics.
const
AuthMutationPersistence.durable({required AuthMutationAtomicity atomicity, AuthPersistenceOperationReference? reference})
Creates durable persistence semantics.
const
AuthMutationPersistence.external()
Creates external-state persistence semantics.
const
AuthMutationPersistence.session()
Creates session-state persistence semantics.
const

Properties

atomicity AuthMutationAtomicity
Atomicity guarantee for durable persistence.
final
hashCode int
The hash code for this object.
no setterinherited
kind AuthMutationPersistenceKind
Persistence boundary that owns the mutation.
final
reference AuthPersistenceOperationReference?
Schema and operation reference for durable persistence, when supplied.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited