AuthNoopUserDeletionPlan class final

Domain-bound namespace marker for plugins whose user state is stored wholly inside core persistence and therefore needs no additional mutation.

Implemented types

Constructors

AuthNoopUserDeletionPlan({required AuthUserDeletionDomain domain, required String userId, required String namespace})
Creates an instance of AuthNoopUserDeletionPlan.

Properties

domain AuthUserDeletionDomain
The domain associated with this value.
final
hashCode int
The hash code for this object.
no setterinherited
namespace String
The namespace associated with this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
The identifier of the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited