AuthOrganizationInternalFailure class final

Failure details for auth organization internal failure.

Constructors

AuthOrganizationInternalFailure({required String operation, required Object error, required StackTrace stackTrace, String? organizationId})
Creates an instance of AuthOrganizationInternalFailure.
const

Properties

error Object
The error associated with this value.
final
hashCode int
The hash code for this object.
no setterinherited
operation String
The operation associated with this value.
final
organizationId String?
The identifier of the organization.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
The stack trace captured for the failure.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited