AuthOrganizationInvitationAcceptance class final

Constructors

AuthOrganizationInvitationAcceptance({required String invitationId, required String email, required AuthOrganizationMember membership, required int? membershipLimit, AuthOrganizationTeamMember? teamMembership, int? teamMemberLimit, required DateTime now})
const

Properties

email String
final
hashCode int
The hash code for this object.
no setterinherited
invitationId String
final
membership AuthOrganizationMember
final
membershipLimit int?
final
now DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teamMemberLimit int?
final
teamMembership AuthOrganizationTeamMember?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited