AuthPasswordPolicyRequest<TContext> class final

Request passed to password policy contributors.

password is a secret and exists only for the duration of the policy call. This type intentionally has no JSON or diagnostic representation.

Constructors

AuthPasswordPolicyRequest({required TContext context, required AuthPasswordPolicyOperation operation, required String password, AuthUser? user})
Creates a request for a password policy contributor.
const

Properties

context → TContext
Framework context associated with the password operation.
final
hashCode int
The hash code for this object.
no setterinherited
operation AuthPasswordPolicyOperation
Password operation being evaluated.
final
password String
Plaintext password supplied only for the duration of the policy call.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user AuthUser?
Existing user associated with the operation, when known.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited