AuthPersistenceSchema class final
Describes the persistence topology owned by an auth plugin.
Constructors
-
AuthPersistenceSchema({required String id, required List<
AuthEntityDescriptor> entities, List<AuthAtomicOperationDescriptor> atomicOperations = const <AuthAtomicOperationDescriptor>[]}) -
Creates a persistence schema descriptor.
const
Properties
-
atomicOperations
→ List<
AuthAtomicOperationDescriptor> -
Atomic operations supported by this schema.
final
-
entities
→ List<
AuthEntityDescriptor> -
Entities stored by this schema.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable schema identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited