AuthPhoneNumberIssueStatus enum

Outcomes of an atomic phone-code issue command.

Inheritance
Available extensions

Values

issued → const AuthPhoneNumberIssueStatus

A new challenge was committed.

replayed → const AuthPhoneNumberIssueStatus

An identical issue command replayed an existing challenge.

replayMismatch → const AuthPhoneNumberIssueStatus

The command ID was reused with different challenge data.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthPhoneNumberIssueStatus>
A constant List of the values in this enum, in order of their declaration.