AuthRateLimitOperation class final

Stable namespaced identifier for a rate-limited auth operation.

Constructors

AuthRateLimitOperation(String namespace, String name)
const
AuthRateLimitOperation.core(AuthRateLimitAction action)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
no setter
legacyAction AuthRateLimitAction?
no setter
name String
final
namespace String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override