AuthRelationshipDescriptor class final

Constructors

AuthRelationshipDescriptor({required String field, required String targetEntity, bool cascadeDelete = false})
const

Properties

cascadeDelete bool
final
field String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetEntity String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited