AuthRouteParameterKey class final

A declared key for one dynamic auth route segment.

Constructors

AuthRouteParameterKey(String name)
Creates a typed key for a route parameter named name.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
Name of the route parameter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override