AuthScimConnectionPage class final
Bounded connection catalog page.
Constructors
-
AuthScimConnectionPage({required List<
AuthScimManagedConnection> items, required int total, required int limit, required int offset}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited