AuthScimCredential class final

Safe credential metadata returned by management APIs.

Constructors

AuthScimCredential({required String id, required String connectionId, required String name, required String keyPrefix, required Set<AuthScimScope> scopes, required DateTime createdAt, required DateTime updatedAt, required bool active, DateTime? expiresAt, DateTime? lastUsedAt, DateTime? revokedAt})
Creates public credential metadata.
const
AuthScimCredential.fromJson(Map<String, dynamic> json)
Decodes and validates public credential metadata.
factory

Properties

active bool
Whether the credential is usable at projection time.
final
connectionId String
Connection that owns this credential.
final
createdAt DateTime
Creation timestamp in UTC.
final
expiresAt DateTime?
Expiry timestamp, when configured.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Stable credential identifier.
final
keyPrefix String
Non-secret prefix used to identify the credential.
final
lastUsedAt DateTime?
Last successful-use timestamp, when known.
final
name String
Human-readable credential name.
final
revokedAt DateTime?
Revocation timestamp, when revoked.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes Set<AuthScimScope>
Scopes granted by this credential.
final
updatedAt DateTime
Last update timestamp in UTC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes the public credential representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited