AuthScimListUsersQuery class final
Bounded query supplied to AuthScimProvisioningStore.listUsers.
Constructors
- AuthScimListUsersQuery({required int startIndex, required int count, AuthScimUserFilter? filter})
-
const
-
AuthScimListUsersQuery.fromJson(Map<
String, dynamic> json, {required int defaultPageSize, required int maximumPageSize, required int maximumStartIndex}) -
factory
Properties
- count → int
-
final
- filter → AuthScimUserFilter?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startIndex → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited