AuthScimResourceMeta class final
SCIM resource metadata supplied by the application provisioning store.
Constructors
Properties
- created → DateTime
-
Resource creation timestamp.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastModified → DateTime
-
Last modification timestamp.
final
- location → Uri?
-
Resource location, when exposed by the application.
final
- resourceType → String
-
SCIM resource type name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String?
-
Application version or entity tag, when available.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this resource metadata object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited