AuthSessionClient class final

Constructors

AuthSessionClient(AuthClientCore _core)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

current() Future<AuthSession?>
getCsrfToken() Future<String>
list() Future<List<AuthClientSession>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revoke(String sessionId) Future<void>
revokeOthers() Future<int>
signOut() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited