AuthSessionResolution class
Result of resolving an auth session for a selected strategy.
Constructors
- AuthSessionResolution({AuthSession? session, Cookie? refreshCookie})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- refreshCookie → Cookie?
-
Reissued JWT cookie when refresh was required.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → AuthSession?
-
Resolved auth session;
nullwhen no session is available.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited