AuthTwoFactorBeginEnrollmentCommand class
Atomically starts or replaces an unverified enrollment.
Constructors
- AuthTwoFactorBeginEnrollmentCommand(AuthTwoFactorRecord record)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- record → AuthTwoFactorRecord
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited