AuthTwoFactorIssueTrustedDeviceCommand class

Atomically verifies TOTP and creates a trusted-device record.

Constructors

AuthTwoFactorIssueTrustedDeviceCommand({required AuthTwoFactorRecord expectedFactor, required bool valid, required AuthTwoFactorTrustedDeviceRecord trustedDevice, required AuthTwoFactorAttemptPolicy policy})
const

Properties

expectedFactor AuthTwoFactorRecord
final
hashCode int
The hash code for this object.
no setterinherited
policy AuthTwoFactorAttemptPolicy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trustedDevice AuthTwoFactorTrustedDeviceRecord
final
valid bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited