AuthTwoFactorRevokeTrustedDevicesCommand class

Command that revokes every trusted device for a user.

Constructors

AuthTwoFactorRevokeTrustedDevicesCommand({required String userId, required DateTime now})
Creates the command for revoking trusted devices.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
now DateTime
Revocation time recorded by the backend.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
User whose devices should be revoked.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited