AuthUserDeletionPreflightException class final

Thrown when a deletion plan set cannot describe one complete transaction.

Implemented types

Constructors

AuthUserDeletionPreflightException(String message)
Creates an instance of AuthUserDeletionPreflightException.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message associated with this value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns a diagnostic string representation.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited