AuthUsernameAuthenticationResponse class final

Endpoint response returned after username authentication.

Constructors

AuthUsernameAuthenticationResponse({required String username, required AuthUser user})
Creates an endpoint authentication response.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user AuthUser
User authenticated by the username credential.
final
username String
Canonical username used for authentication.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAuthenticationIntent(AuthProvider provider, {required String authenticationMethod}) AuthEndpointAuthenticationIntent
Converts this response into a framework-neutral authentication intent.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited