AuthUsernameMutationResult class final

Store-confirmed result of a username transaction.

Constructors

AuthUsernameMutationResult({required AuthUsernameMutationStatus status, AuthUser? user, AuthPasswordCredential? credential})
Creates the outcome of a username store transaction.
const

Properties

credential AuthPasswordCredential?
Username credential returned by the store, when available.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AuthUsernameMutationStatus
Transaction outcome.
final
succeeded bool
Whether the transaction created, changed, or preserved a credential.
no setter
user AuthUser?
User projection returned by the store, when available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited