AuthWebAuthnAuthenticationResult class final

Result of a verified passkey assertion.

Constructors

AuthWebAuthnAuthenticationResult({required AuthUser user, required WebAuthnAuthenticator authenticator})
Creates the result of a verified passkey assertion.
const

Properties

authenticator WebAuthnAuthenticator
Credential whose assertion was verified and counter advanced.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user AuthUser
User authenticated by the passkey.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited