AuthWebAuthnRegistrationOptions class final

Public registration options returned to a WebAuthn client.

Constructors

AuthWebAuthnRegistrationOptions({required String challenge, required WebAuthnRelyingParty relyingParty, required String userId, required String userName, required String displayName, required Duration timeout, required String attestation, required List<String> excludeCredentials, required String userVerification})
Creates the public options for a registration ceremony.
const

Properties

attestation String
Attestation conveyance preference.
final
challenge String
Base64url challenge that the authenticator must sign.
final
displayName String
User display name shown to the authenticator.
final
excludeCredentials List<String>
Existing credentials that the authenticator must not register again.
final
hashCode int
The hash code for this object.
no setterinherited
relyingParty WebAuthnRelyingParty
Relying-party identifier and display name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
Maximum duration allowed for the ceremony.
final
userId String
Opaque user handle sent to the authenticator.
final
userName String
User name shown to the authenticator.
final
userVerification String
User-verification requirement sent to the authenticator.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes these options for the browser WebAuthn API.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited