BrowserValidationResult class

Comprehensive browser-request validation result.

Constructors

BrowserValidationResult.invalid(String? errorCode)
Creates a failed result with the stable errorCode.
const
BrowserValidationResult.valid()
Creates a successful result with no error code.
const

Properties

errorCode String?
Stable failure code, or null for a valid result.
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Whether this result represents a successful validation.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valid bool
Whether the request passed browser protection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited