FidoMetadataBlobLoader class final

Parses a caller-supplied compact MDS3 JWT after an explicit JWS check.

Constructors

FidoMetadataBlobLoader({required Iterable<List<int>> trustAnchors, required FidoMetadataJwsVerifier verifyJws, FidoMetadataLimits limits = const FidoMetadataLimits(), FidoMetadataNextUpdatePolicy nextUpdatePolicy = FidoMetadataNextUpdatePolicy.advisory})

Properties

hashCode int
The hash code for this object.
no setterinherited
limits FidoMetadataLimits
final
nextUpdatePolicy FidoMetadataNextUpdatePolicy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verifyJws FidoMetadataJwsVerifier
final

Methods

load(String compact, {required DateTime now, int? previousBlobNumber, Duration clockSkew = Duration.zero}) Future<FidoMetadataBlob>
Loads a downloaded compact blob. No network or cache lookup occurs.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited