FidoMetadataEntry class final

One MetadataBLOBPayloadEntry from an authenticated MDS blob.

Properties

aaguid String?
Authenticator AAGUID used to select this entry, when present.
final
aaid String?
Authenticator AAID used to select this entry, when present.
final
attestationCertificateKeyIdentifiers List<String>
Attestation-certificate key identifiers used to select this entry.
final
hashCode int
The hash code for this object.
no setterinherited
metadataStatement FidoMetadataStatement
Metadata statement describing the authenticator.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusReports List<FidoMetadataStatusReport>
Status reports ordered as supplied by the authenticated MDS blob.
final
timeOfLastStatusChange DateTime
Date of the most recent status change in the entry.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited