FidoMetadataHttpRequest class final

A bounded, single-hop HTTP GET request used by the MDS downloader.

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
maxResponseBytes int
final
maxResponseHeaderBytes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final
uri Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited