FidoMetadataProvenance class final

Safe provenance for a WebAuthn metadata decision.

Properties

attestationAaguid String
AAGUID presented by the attestation.
final
blobNumber int
MDS blob number that supplied the matched entry.
final
entryAaguid String?
AAGUID on the matched entry, when present.
final
hashCode int
The hash code for this object.
no setterinherited
matchKind FidoMetadataMatchKind
Mechanism used to find the matched entry.
final
metadataRootFingerprints List<String>
SHA-256 fingerprints of the metadata roots used by the entry.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status FidoMetadataStatusReport
Current status report used for the trust decision.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited