FidoMetadataVerifiedCertificate class final
Public certificate information supplied to a revocation checker.
Properties
-
derBytes
→ List<
int> -
Exact DER encoding of the certificate.
final
-
extendedKeyUsages
→ List<
String> -
Extended-key-usage object identifiers, when the extension is present.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCertificateAuthority → bool
-
Whether the certificate asserts certificate-authority capabilities.
final
- notAfter → DateTime
-
End of the certificate validity interval.
final
- notBefore → DateTime
-
Start of the certificate validity interval.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumber → BigInt
-
Positive X.509 certificate serial number.
Positive X.509 certificate serial number.
final
- sha256Fingerprint → String
-
Lowercase hexadecimal SHA-256 fingerprint of derBytes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited