GitHubPlan class

GitHub user plan information.

Constructors

GitHubPlan({required int collaborators, required String name, required int space, required int privateRepos})
Creates plan information returned by GitHub.
const
GitHubPlan.fromJson(Map<String, dynamic> json)
Creates plan information from a GitHub API response.
factory

Properties

collaborators int
Number of collaborators included in the plan.
final
hashCode int
The hash code for this object.
no setterinherited
name String
GitHub plan name.
final
privateRepos int
Number of private repositories included in the plan.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
space int
Storage space included in the plan, as reported by GitHub.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this plan using GitHub's response field names.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited