JwtVerifier class

A JWT verifier that validates tokens against configured keys and claims.

Constructors

JwtVerifier({required JwtOptions options, Client? httpClient, JwtClaimsValidator? validateClaims})
Creates a JwtVerifier with the given options and optional httpClient.

Properties

hashCode int
The hash code for this object.
no setterinherited
options JwtOptions
The verification options this verifier was configured with.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validateClaims JwtClaimsValidator?
Optional application-specific claim validator.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verifyToken(String token) Future<JwtPayload>
Verifies a JWT token string and returns its payload.

Operators

operator ==(Object other) bool
The equality operator.
inherited