OAuth2Exception class

Represents an exception that occurs during OAuth2 operations.

Implemented types

Constructors

OAuth2Exception(String message, [int? statusCode])
Creates an OAuth2 exception with an optional HTTP statusCode.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
HTTP status returned by the remote endpoint, when available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited