authorizationCodeExchangeStore property

OAuthAuthorizationCodeExchangeStore authorizationCodeExchangeStore
final

Authoritative exchange capability for authorization-code grants.

The capability owns the code and token stores so provider mode cannot accidentally compose a split, non-atomic exchange topology.

Implementation

final OAuthAuthorizationCodeExchangeStore authorizationCodeExchangeStore;