RbacOptions class

RBAC configuration options.

Constructors

RbacOptions({Map<String, RbacAbility> abilities = const <String, RbacAbility>{}})
Creates options from an ability-name-to-rule map.
const

Properties

abilities Map<String, RbacAbility>
Ability -> role mapping.
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Returns true when there are abilities to register.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited