AuthAdminStoreConformanceCase class final
One independently runnable admin-store conformance case.
Properties
- description → String
-
Human-readable behavior covered by this case.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable machine-readable case identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< AuthAdminStoreConformanceResult> - Runs this conformance case.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited