AuthAdminStoreConformanceFailure class final

Describes a failed admin-store conformance case.

Implemented types

Constructors

AuthAdminStoreConformanceFailure({required String caseId, required Object cause})
Creates a failure for caseId caused by cause.
const

Properties

caseId String
Stable identifier of the failed case.
final
cause Object
Error raised by the adapter or the failed expectation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited