AuthAnonymousStoreConformanceCase class final

One independently runnable anonymous-store conformance case.

Constructors

AuthAnonymousStoreConformanceCase({required String id, required String description, required Future<void> run()})
Creates a runnable conformance case.
const

Properties

description String
Human-readable behavior covered by this case.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Stable machine-readable case identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() Future<void>
Runs this conformance case.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited