AuthApiKeyStoreConformanceSuite class final

Reusable lifecycle, bound, contention, and rollback contract for API keys.

Constructors

AuthApiKeyStoreConformanceSuite(AuthApiKeyStoreConformanceFactory createFixture)
Creates a suite backed by createFixture.

Properties

cases List<AuthApiKeyStoreConformanceCase>
The isolated cases exposed by this suite.
no setter
createFixture AuthApiKeyStoreConformanceFactory
Creates an isolated fixture with the requested record limit. Creates an isolated fixture with the requested record limit.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited