createFixture property

AuthApiKeyStoreConformanceFactory createFixture
final

Creates an isolated fixture with the requested record limit. Creates an isolated fixture with the requested record limit.

Implementation

final AuthApiKeyStoreConformanceFactory createFixture;