AuthClientConformanceResponse class final
One HTTP response used to exercise an installed client operation.
Constructors
-
AuthClientConformanceResponse.json(Object? body, {int statusCode = 200, Map<
String, String> headers = const <String, String>{}}) -
Creates a JSON response.
const
-
AuthClientConformanceResponse.raw(String body, {int statusCode = 200, Map<
String, String> headers = const <String, String>{}}) -
Creates a raw response, useful for malformed-codec cases.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
HTTP response headers returned to the installed client operation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status returned to the installed client operation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited