response property
Successful response accepted by both server and client codecs.
Implementation
final AuthClientConformanceResponse response;
Successful response accepted by both server and client codecs.
final AuthClientConformanceResponse response;