origin property
Stable provider origin used by token and userinfo requests.
Implementation
static final Uri origin = Uri.parse('https://provider.example.test');
Stable provider origin used by token and userinfo requests.
static final Uri origin = Uri.parse('https://provider.example.test');