AuthPhoneOtpFixture<TContext> class final

Captures phone OTP delivery and supplies deterministic numeric codes.

Constructors

AuthPhoneOtpFixture({Iterable<String> codes = const <String>['123456']})
Creates a phone OTP fixture from codes.

Properties

deliveries AuthTestDeliveryLog<AuthPhoneNumberCodeDelivery<TContext>>
Raw delivery payloads retained in memory for the test only.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plugin({Duration expiresIn = const Duration(minutes: 5), int allowedAttempts = 3, bool allowSignUp = true}) PhoneNumberPlugin<TContext>
Creates a real phone plugin.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited