AuthPluginConformanceCase class final
One independently runnable plugin-composition conformance case.
Properties
- description → String
-
Human-readable behavior covered by this case.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable machine-readable case identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< AuthPluginConformanceResult> - Runs this case against the captured, immutable runtime topology.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited