AuthSamlVerifierConformanceVector class final

Constructors

AuthSamlVerifierConformanceVector({required AuthSamlVerificationInput valid, required Map<String, AuthSamlVerificationInput> hostile})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hostile Map<String, AuthSamlVerificationInput>
Modified, wrapping, duplicate-ID, reference-substitution, and algorithm confusion documents that the verifier must reject.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valid AuthSamlVerificationInput
A real, cryptographically valid response for the pinned test IdP.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited