hostile property
Modified, wrapping, duplicate-ID, reference-substitution, and algorithm confusion documents that the verifier must reject.
Implementation
final Map<String, AuthSamlVerificationInput> hostile;
Modified, wrapping, duplicate-ID, reference-substitution, and algorithm confusion documents that the verifier must reject.
final Map<String, AuthSamlVerificationInput> hostile;