AuthScimApplicationProjectionStoreConformanceFixture class final

Supplies the projection store and lifecycle hooks used by a case.

Constructors

AuthScimApplicationProjectionStoreConformanceFixture({required AuthScimApplicationProjectionStore store, required AuthScimApplicationProjectionStoreConformanceFaultController faults, FutureOr<void> dispose()?})
Creates a fixture from the projection store and fault controller.
const

Properties

dispose FutureOr<void> Function()?
Releases resources owned by the fixture.
final
faults AuthScimApplicationProjectionStoreConformanceFaultController
Fault controller for rollback cases.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store AuthScimApplicationProjectionStore
Application-owned projection store under test.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited