AuthStoreConformanceResult class final

The result of running one conformance case.

Constructors

AuthStoreConformanceResult.passed()
Creates a successful result.
const
AuthStoreConformanceResult.skipped(String reason)
Creates a result for an optional capability the adapter does not expose.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isSkipped bool
Whether the adapter did not expose the case's optional capability.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skippedReason String?
Why the case was skipped, or null when it passed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited