failNext method
Configures the next capture call to throw error after recording it.
Implementation
void failNext(Object error, [StackTrace? stackTrace]) {
_nextError = error;
_nextStackTrace = stackTrace;
}
Configures the next capture call to throw error after recording it.
void failNext(Object error, [StackTrace? stackTrace]) {
_nextError = error;
_nextStackTrace = stackTrace;
}