gateNext method
Pauses the next capture call at gate after recording the payload.
Implementation
void gateNext(AuthTestGate gate) => _nextGate = gate;
Pauses the next capture call at gate after recording the payload.
void gateNext(AuthTestGate gate) => _nextGate = gate;