AuthTestGate class final

A manually released gate for deterministic contention tests.

Constructors

AuthTestGate()

Properties

entered Future<void>
Completes when a fixture reaches the gate.
no setter
hashCode int
The hash code for this object.
no setterinherited
isReleased bool
Whether release has been called.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
Allows every waiter to continue.
toString() String
A string representation of this object.
inherited
wait() Future<void>
Waits until the test calls release.

Operators

operator ==(Object other) bool
The equality operator.
inherited