AuthTestSequence<T> class final

A deterministic finite sequence for test-only tokens, codes, and IDs.

Values are supplied by the test. No value from this sequence should be reused as an application secret.

Constructors

AuthTestSequence(Iterable<T> values)
Creates a sequence consumed in insertion order.

Properties

hashCode int
The hash code for this object.
no setterinherited
remaining int
Number of values that have not been consumed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

next() → T
Returns the next value or throws when the fixture is exhausted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited