AuthTwoFactorBackendConformanceFailure class final

Identifies a failed durable two-factor backend conformance case.

Implemented types

Constructors

AuthTwoFactorBackendConformanceFailure(String caseId, Object cause)
const

Properties

caseId String
final
cause Object
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited