AuthTwoFactorClientFixture class final

Deterministic two-factor response values for typed client codec tests.

Constructors

AuthTwoFactorClientFixture(DateTime now)
Creates a two-factor client fixture using now for expirations.

Properties

hashCode int
The hash code for this object.
no setterinherited
now DateTime
Current instant used to calculate fixture expiration values.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enrollment() Map<String, dynamic>
Enrollment response with an obvious test-only TOTP secret.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recoveryCodes() Map<String, dynamic>
One-time recovery-code response.
status() Map<String, dynamic>
Enabled status response.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited