AuthWebAuthnStoreConformanceFixture class final

Supplies WebAuthn capabilities and lifecycle hooks used by a case.

Constructors

AuthWebAuthnStoreConformanceFixture({required AuthWebAuthnStoreCapabilities capabilities, FutureOr<void> dispose()?})
Creates a fixture from WebAuthn capabilities and an optional disposer.
const

Properties

capabilities AuthWebAuthnStoreCapabilities
WebAuthn persistence capabilities under test.
final
dispose FutureOr<void> Function()?
Releases resources owned by the fixture.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited