AuthAccountDeletionInitiated class
Result of initiating account deletion.
Constructors
- AuthAccountDeletionInitiated({required String userId, required String? email, required String confirmationToken, required DateTime expiresAt})
-
Creates an instance of AuthAccountDeletionInitiated.
const
Properties
- confirmationToken → String
-
Raw confirmation token (for delivery only).
final
- email → String?
-
Email address for confirmation delivery.
final
- expiresAt → DateTime
-
When the confirmation token expires.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
ID of the user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited