AuthAdminOptions<TContext> class
final
Configuration for administrative operations.
Constructors
-
AuthAdminOptions({Set<
String> adminRoles = const {'admin'}, Set<String> adminUserIds = const {}, Map<String, AuthAdminPermissionSet> ? roles, String defaultRole = 'user', String defaultBanReason = 'No reason provided', Duration impersonationDuration = const Duration(hours: 1), int maximumPageSize = 100, AuthAdminHooks<TContext> hooks = const AuthAdminHooks(), AuthAdminDeletionGuard? validateDeletion, AuthAdminFailureReporter? reportFailure, AuthAdminEventSink? emitEvent}) -
Creates an instance of AuthAdminOptions.
const
Properties
-
adminRoles
→ Set<
String> -
The roles assigned to this value.
final
-
adminUserIds
→ Set<
String> -
The admin user ids associated with this value.
final
- defaultBanReason → String
-
The reason associated with this value.
final
- defaultRole → String
-
The roles assigned to this value.
final
- emitEvent → AuthAdminEventSink?
-
The emit event associated with this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hooks
→ AuthAdminHooks<
TContext> -
Lifecycle hooks invoked by this component.
final
- impersonationDuration → Duration
-
The duration used by this value.
final
- maximumPageSize → int
-
The maximum page size associated with this value.
final
- reportFailure → AuthAdminFailureReporter?
-
The report failure associated with this value.
final
-
roles
→ Map<
String, AuthAdminPermissionSet> ? -
The roles assigned to this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validateDeletion → AuthAdminDeletionGuard?
-
The validate deletion associated with this value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited