AuthApiKeyClient class final
Client for issuing and managing API keys for the current user.
Constructors
- AuthApiKeyClient(AuthClientCore _core)
- Creates an API-key client backed by the shared client transport.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
{required String name, Iterable< String> scopes = const <String>[], DateTime? expiresAt}) → Future<AuthClientIssuedApiKey> -
Creates a key with
name,scopes, and optionalexpiresAt. -
exchangeForSession(
) → Future< AuthSession> - Exchanges the presented API key for a normal auth session.
-
list(
) → Future< List< AuthClientApiKey> > - Lists the current user's API-key metadata.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revoke(
{required String id}) → Future< void> -
Revokes the API key identified by
id. -
rotate(
{required String id, String? name, Iterable< String> ? scopes, DateTime? expiresAt}) → Future<AuthClientIssuedApiKey> -
Rotates the API key identified by
id. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited