AuthAuthenticationMethodKind enum
Built-in kinds understood by the account-safety inventory.
Values
- password → const AuthAuthenticationMethodKind
-
A password-backed credential.
- oauthProvider → const AuthAuthenticationMethodKind
-
An account linked through an external OAuth provider.
- passkey → const AuthAuthenticationMethodKind
-
A WebAuthn or passkey credential.
- phone → const AuthAuthenticationMethodKind
-
A phone-number authentication method.
- emailOtp → const AuthAuthenticationMethodKind
-
A one-time password delivered through email.
- emailLink → const AuthAuthenticationMethodKind
-
An email-link authentication method.
- username → const AuthAuthenticationMethodKind
-
A username-backed authentication method.
- apiKey → const AuthAuthenticationMethodKind
-
An API key that is eligible to authenticate as the user.
- plugin → const AuthAuthenticationMethodKind
-
An authentication method supplied by another plugin.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthAuthenticationMethodKind> - A constant List of the values in this enum, in order of their declaration.