AuthBreachedPasswordPluginConfig class final
Typed limits and operation selection for breached-password checks.
Constructors
Properties
- checkPasswordChange → bool
-
Whether authenticated password changes are checked.
final
- checkPasswordReset → bool
-
Whether password-reset replacement passwords are checked.
final
- checkRegistration → bool
-
Whether registration passwords are checked.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxPasswordLength → int
-
Maximum password length passed to the lookup service.
final
- providerTimeout → Duration
-
Maximum time allowed for one application-owned lookup.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited