AuthCallbackProviderOutcome class
Framework-agnostic normalized outcome for callback-provider results.
Constructors
- AuthCallbackProviderOutcome.failure(String? errorCode)
-
const
- AuthCallbackProviderOutcome.success({required AuthUser? user, String? redirectUrl})
-
const
Properties
- errorCode → String?
-
Canonical auth error code when callback fails.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
Whether callback resolution succeeded.
no setter
- redirectUrl → String?
-
Optional redirect URL when callback succeeds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → AuthUser?
-
Authenticated user when callback succeeds.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited