A typed, opt-in client API.
A plugin should expose only the operations owned by one server plugin or provider. Applications install the client plugins they use instead of receiving every optional auth operation on one client object.
- Implementers
- AuthAccountClientPlugin
- AuthAdminClientPlugin
- AuthAnonymousClientPlugin
- AuthApiKeyClientPlugin
- AuthCaptchaClientPlugin
- AuthCredentialsClientPlugin
- AuthDeviceAuthorizationClientPlugin
- AuthEmailOtpClientPlugin
- AuthLastAuthenticationMethodClientPlugin
- AuthMagicLinkClientPlugin
- AuthOAuthClientPlugin
- AuthOrganizationClientPlugin
- AuthPasswordClientPlugin
- AuthPhoneNumberClientPlugin
- AuthProviderClientPlugin
- AuthSamlClientPlugin
- AuthScimConnectionClientPlugin
- AuthSessionClientPlugin
- AuthTwoFactorClientPlugin
- AuthUsernameClientPlugin
- AuthWebAuthnClientPlugin
Properties
Methods
-
install(
AuthClientPluginContext context) → TApi - Builds the typed API exposed by this plugin.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited