AuthCredentialsClientPlugin class final
Adds username-and-password operations to an AuthClient.
- Implemented types
Constructors
- AuthCredentialsClientPlugin({String provider = 'credentials'})
-
Creates a credentials plugin for
provider.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable registry identifier for this provider-specific plugin.
no setteroverride
- provider → String
-
Provider identifier used for credential requests.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
install(
AuthClientPluginContext context) → AuthCredentialsClient -
Installs the credentials client backed by
context.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited