AuthEmailChangeToken class

One-time confirmation token for changing a user's email address.

The raw token is delivery-only. Typed stores must persist only its digest and return this value only to the caller that atomically consumes it.

Constructors

AuthEmailChangeToken({required String userId, required String newEmail, required String token, required DateTime expiresAt})

Properties

expiresAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
newEmail String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited