Persistence contract for one-time email-change confirmations.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
consume(
String token) → FutureOr< AuthEmailChangeToken?> - Atomically consumes an active token and returns its user/email binding.
-
deleteForUser(
String userId) → FutureOr< void> -
Deletes all pending email-change tokens for
userId. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
AuthEmailChangeToken token) → FutureOr< void> - Persists a pending email-change token.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited