Optional protocol-specific public errors for failures owned by the host.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createPublicErrorResponse(
AuthEndpointPublicErrorKind kind) → AuthEndpointHttpResponse? -
Creates a public response for
kind, when the endpoint supports it. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited