AuthGateEvaluation<TContext> class
Result payload emitted after a gate evaluation.
Constructors
- AuthGateEvaluation({required String ability, required bool allowed, required TContext context, required AuthPrincipal? principal, Object? payload})
- Creates the observer event emitted after a gate callback completes.
Properties
- ability → String
-
The evaluated ability.
final
- allowed → bool
-
Whether the ability was allowed.
final
- context → TContext
-
Framework/runtime context.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload → Object?
-
Optional payload associated with the evaluation.
final
- principal → AuthPrincipal?
-
The authenticated principal, if available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited