AuthLastAuthenticationMethodCookie class final
Host-owned browser cookie instructions produced by the plugin.
Constructors
- AuthLastAuthenticationMethodCookie({required String name, required String value, required String path, required AuthLastAuthenticationMethodSameSite sameSite, int? maxAge, bool secure = true, bool httpOnly = true})
- Creates host-owned cookie instructions for the last-method state.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpOnly → bool
-
Whether the cookie is inaccessible to client-side scripts.
final
- maxAge → int?
-
Max-age in seconds, or null for a session cookie.
final
- name → String
-
Cookie name.
final
- path → String
-
Cookie path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameSite → AuthLastAuthenticationMethodSameSite
-
Cookie SameSite policy.
final
- secure → bool
-
Whether the cookie is restricted to HTTPS.
final
- value → String
-
Encoded signed state, or an empty value when clearing the cookie.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited