AuthOAuthCallbackSignInResolution class
Result of resolving an OAuth callback into sign-in payloads and callback redirect metadata.
Constructors
- AuthOAuthCallbackSignInResolution({required AuthOAuthSignInResolution signIn, required String? callbackUrl})
-
const
Properties
- callbackUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signIn → AuthOAuthSignInResolution
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited