Persistence boundary for one-time OAuth authorization challenges.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
consume(
String providerId, String state) → FutureOr< AuthOAuthChallenge?> - Atomically consumes a matching, unexpired challenge.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
AuthOAuthChallenge challenge) → FutureOr< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited