AuthOrganizationAuthorizationContext<TContext> class
final
Explicit tenant authorization context. Organization roles stay separate from global principal roles.
Constructors
-
AuthOrganizationAuthorizationContext({required TContext context, required String userId, required AuthOrganization organization, required AuthOrganizationMember membership, AuthOrganizationTeam? team, List<
AuthOrganizationRole> authorizationRoleSnapshots = const <AuthOrganizationRole>[]}) -
Creates an instance of AuthOrganizationAuthorizationContext.
const
Properties
-
The roles assigned to this value.
final
- context → TContext
-
The host context associated with this operation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- membership → AuthOrganizationMember
-
The membership associated with this value.
final
- organization → AuthOrganization
-
The organization associated with this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- team → AuthOrganizationTeam?
-
The team associated with this value.
final
- userId → String
-
The identifier of the user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ownsUser(
String resourceUserId) → bool - Performs the owns user operation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited