AuthOrganizationCreateInvitationCommand class final
Command describing auth organization create invitation command.
- Inheritance
-
- Object
- AuthOrganizationStoreCommand<
AuthOrganizationStoreMutationResult< AuthOrganizationInvitation> > - AuthOrganizationCreateInvitationCommand
Constructors
-
AuthOrganizationCreateInvitationCommand({required AuthOrganizationMember actorMembership, required AuthOrganizationInvitation invitation, required int? invitationLimit, required bool replacePending, required AuthOrganizationIdempotency idempotency, Iterable<
AuthOrganizationRole> actorRoleSnapshots = const <AuthOrganizationRole>[]}) - Creates an instance of AuthOrganizationCreateInvitationCommand.
Properties
- actorMembership → AuthOrganizationMember
-
The actor membership associated with this value.
final
-
actorRoleSnapshots
→ List<
AuthOrganizationRole> -
The roles assigned to this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotency → AuthOrganizationIdempotency
-
The idempotency associated with this value.
final
- invitation → AuthOrganizationInvitation
-
The invitation associated with this value.
final
- invitationLimit → int?
-
The invitation limit associated with this value.
final
- replacePending → bool
-
The replace pending associated with this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited