AuthOrganizationCreateTransaction class final
Authentication data for auth organization create transaction.
Constructors
- AuthOrganizationCreateTransaction({required AuthOrganization organization, required AuthOrganizationMember creatorMembership, required int? organizationLimit, AuthOrganizationTeam? defaultTeam, AuthOrganizationTeamMember? creatorTeamMembership, AuthOrganizationIdempotency? idempotency})
-
Creates an instance of AuthOrganizationCreateTransaction.
const
Properties
- creatorMembership → AuthOrganizationMember
-
The creator membership associated with this value.
final
- creatorTeamMembership → AuthOrganizationTeamMember?
-
The creator team membership associated with this value.
final
- defaultTeam → AuthOrganizationTeam?
-
The default team associated with this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotency → AuthOrganizationIdempotency?
-
The idempotency associated with this value.
final
- organization → AuthOrganization
-
The organization associated with this value.
final
- organizationLimit → int?
-
The organization limit associated with this value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited