AuthOrganizationHooks<TContext> class
final
Authentication data for auth organization hooks.
Constructors
-
AuthOrganizationHooks({AuthOrganizationBeforeHook<
TContext, AuthOrganization> ? beforeOrganization, AuthOrganizationAfterHook<TContext, AuthOrganization> ? afterOrganization, AuthOrganizationBeforeHook<TContext, AuthOrganizationMember> ? beforeMember, AuthOrganizationAfterHook<TContext, AuthOrganizationMember> ? afterMember, AuthOrganizationBeforeHook<TContext, AuthOrganizationInvitation> ? beforeInvitation, AuthOrganizationAfterHook<TContext, AuthOrganizationInvitation> ? afterInvitation, AuthOrganizationBeforeHook<TContext, AuthOrganizationRole> ? beforeRole, AuthOrganizationAfterHook<TContext, AuthOrganizationRole> ? afterRole, AuthOrganizationBeforeHook<TContext, AuthOrganizationTeam> ? beforeTeam, AuthOrganizationAfterHook<TContext, AuthOrganizationTeam> ? afterTeam, AuthOrganizationBeforeHook<TContext, AuthOrganizationTeamMember> ? beforeTeamMember, AuthOrganizationAfterHook<TContext, AuthOrganizationTeamMember> ? afterTeamMember}) -
Creates an instance of AuthOrganizationHooks.
const
Properties
-
afterInvitation
→ AuthOrganizationAfterHook<
TContext, AuthOrganizationInvitation> ? -
The after invitation associated with this value.
final
-
afterMember
→ AuthOrganizationAfterHook<
TContext, AuthOrganizationMember> ? -
The after member associated with this value.
final
-
afterOrganization
→ AuthOrganizationAfterHook<
TContext, AuthOrganization> ? -
The after organization associated with this value.
final
-
afterRole
→ AuthOrganizationAfterHook<
TContext, AuthOrganizationRole> ? -
The roles assigned to this value.
final
-
afterTeam
→ AuthOrganizationAfterHook<
TContext, AuthOrganizationTeam> ? -
The after team associated with this value.
final
-
afterTeamMember
→ AuthOrganizationAfterHook<
TContext, AuthOrganizationTeamMember> ? -
The after team member associated with this value.
final
-
beforeInvitation
→ AuthOrganizationBeforeHook<
TContext, AuthOrganizationInvitation> ? -
The before invitation associated with this value.
final
-
beforeMember
→ AuthOrganizationBeforeHook<
TContext, AuthOrganizationMember> ? -
The before member associated with this value.
final
-
beforeOrganization
→ AuthOrganizationBeforeHook<
TContext, AuthOrganization> ? -
The before organization associated with this value.
final
-
beforeRole
→ AuthOrganizationBeforeHook<
TContext, AuthOrganizationRole> ? -
The roles assigned to this value.
final
-
beforeTeam
→ AuthOrganizationBeforeHook<
TContext, AuthOrganizationTeam> ? -
The before team associated with this value.
final
-
beforeTeamMember
→ AuthOrganizationBeforeHook<
TContext, AuthOrganizationTeamMember> ? -
The before team member associated with this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited