AuthPasswordClient class final
Client for changing passwords and confirming email changes.
Constructors
- AuthPasswordClient(AuthClientCore _core)
- Creates a password client backed by the shared client transport.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
change(
{required String identifier, required String currentPassword, required String newPassword}) → Future< void> -
Changes the password for
identifier. -
confirmEmailChange(
{required String token}) → Future< AuthUser> -
Confirms a pending email change using
token. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reauthenticate(
{required String currentPassword, String? identifier}) → Future< void> -
Re-authenticates the current user with
currentPassword. -
requestEmailChange(
{required String newEmail, required String currentPassword, String? identifier}) → Future< void> -
Requests a change to
newEmail. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited