AuthPhoneNumberVerifyRequest class final
JSON request for verifying a phone verification code.
Constructors
- AuthPhoneNumberVerifyRequest({required String phoneNumber, required String code, String? name})
-
Creates a phone-code verification request.
const
-
AuthPhoneNumberVerifyRequest.fromJson(Map<
String, dynamic> json) -
Decodes a verification request from JSON.
factory
Properties
- code → String
-
Raw verification code supplied by the caller.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
Optional display name for a newly created user.
final
- phoneNumber → String
-
Phone number associated with the code.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Encodes this request as JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited