AuthPhoneNumberVerifyResult class final
Store result returned by an atomic phone-code verification command.
Constructors
- AuthPhoneNumberVerifyResult(AuthPhoneNumberVerifyStatus status, {AuthPhoneNumberVerification? verification, AuthPhoneNumberIdentity? identity, AuthUser? user})
-
Creates the outcome of a phone-code verification command.
const
Properties
- committed → bool
-
Whether the operation committed the phone identity.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity → AuthPhoneNumberIdentity?
-
Identity committed by a successful verification.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AuthPhoneNumberVerifyStatus
-
Outcome of the verification operation.
final
- user → AuthUser?
-
User resolved or created by a successful verification.
final
- verification → AuthPhoneNumberVerification?
-
Updated challenge, when the store can return it.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited