AuthRateLimitDecision class final
Result returned by an AuthRateLimiter.
Constructors
- AuthRateLimitDecision.allow()
-
const
- AuthRateLimitDecision.block({required Duration retryAfter})
-
const
Properties
- allowed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- retryAfter → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited