AuthResolvedJwtSession class
Resolved JWT session payload after optional refresh processing.
Constructors
- AuthResolvedJwtSession({required String token, required AuthUser user, required DateTime? expiresAt, required JwtPayload payload, Cookie? refreshCookie})
-
Creates a resolved session result.
const
Properties
- expiresAt → DateTime?
-
Expiration time of token, if present.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload → JwtPayload
-
Payload from the verified token.
final
- refreshCookie → Cookie?
-
Replacement cookie when the token was refreshed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
Serialized JWT to use for the resolved session.
final
- user → AuthUser
-
User reconstructed from the verified JWT claims.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSession(
{AuthSessionStrategy strategy = AuthSessionStrategy.jwt}) → AuthSession - Converts this result into a framework-neutral auth session.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited