AuthRouteParameterKey class final
A declared key for one dynamic auth route segment.
Constructors
- AuthRouteParameterKey(String name)
-
Creates a typed key for a route parameter named
name.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override