AuthSamlRedirectPolicy class final
Allow-list policy for SAML callback URIs.
Constructors
-
AuthSamlRedirectPolicy({bool allowRelative = true, Set<
Uri> trustedOrigins = const <Uri>{}}) -
Creates a policy allowing relative callbacks and
trustedOrigins. - AuthSamlRedirectPolicy.relativeOnly()
-
Creates a policy that accepts only root-relative callback paths.
const
Properties
- allowRelative → bool
-
Whether root-relative callback paths are accepted.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trustedOrigins
→ Set<
Uri> -
Trusted URI origins allowed for absolute callbacks.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
project(
String? candidate, {required Uri fallback}) → Uri -
Validates
candidate, falling back tofallbackwhen it is blank. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited