AuthSamlSignatureProof class final
Proof returned by an application-owned XMLDSig implementation.
The verifier must cryptographically validate the pinned IdP certificate and return the exact IDs referenced by the validated signature. Returning IDs discovered elsewhere in the document violates this contract.
Constructors
Properties
- canonicalizationAlgorithm → String
-
The canonicalization algorithm URI.
final
- digestAlgorithm → String
-
The XMLDSig digest algorithm URI.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signatureAlgorithm → String
-
The XMLDSig signature algorithm URI.
final
- signedAssertionId → String?
-
The assertion ID referenced by a validated signature, if any.
final
- signedResponseId → String?
-
The response ID referenced by a validated signature, if any.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited