AuthScimConnectionIdentity class final
Immutable connection identity resolved atomically from one bearer token.
The application-owned resolver must return the connection and all of its isolation boundaries in one result. Routed performs no secondary tenant or connection lookup after authentication.
Constructors
-
AuthScimConnectionIdentity({required String connectionId, required String credentialId, required String tenantId, required String organizationId, required String provisioningDomainId, required String subjectId, required Iterable<
AuthScimScope> scopes, DateTime? expiresAt})
Properties
- connectionId → String
-
final
- credentialId → String
-
final
- expiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizationId → String
-
final
- provisioningDomainId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ Set<
AuthScimScope> -
final
- subjectId → String
-
final
- tenantId → String
-
final
Methods
-
allows(
AuthScimScope scope) → bool -
isExpiredAt(
DateTime instant) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited