AuthScimConnectionManagementOperation enum
Management permission checked by the application-owned authorizer.
Values
- create → const AuthScimConnectionManagementOperation
-
Creates a connection.
- list → const AuthScimConnectionManagementOperation
-
Lists connections.
- update → const AuthScimConnectionManagementOperation
-
Updates a connection.
- disable → const AuthScimConnectionManagementOperation
-
Disables a connection.
- credentialsList → const AuthScimConnectionManagementOperation
-
Lists connection credentials.
- credentialsIssue → const AuthScimConnectionManagementOperation
-
Issues a connection credential.
- credentialsRotate → const AuthScimConnectionManagementOperation
-
Rotates a connection credential.
- credentialsRevoke → const AuthScimConnectionManagementOperation
-
Revokes a connection credential.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthScimConnectionManagementOperation> - A constant List of the values in this enum, in order of their declaration.