AuthScimUser class final
Connection-bound SCIM User resource returned by an application store.
Constructors
- AuthScimUser({required String connectionId, required String tenantId, required String organizationId, required String provisioningDomainId, required String id, required AuthScimUserData data, required AuthScimResourceMeta meta, required AuthScimDirectoryUserState state, DateTime? tombstonedAt})
Properties
- connectionId → String
-
Immutable connection that owns this directory resource.
final
- data → AuthScimUserData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- meta → AuthScimResourceMeta
-
final
- organizationId → String
-
Internal organization boundary. It is deliberately omitted from JSON.
final
- provisioningDomainId → String
-
Application boundary receiving explicit provisioning projections.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → AuthScimDirectoryUserState
-
final
- tenantId → String
-
Internal tenancy boundary. It is deliberately omitted from SCIM JSON.
final
- tombstonedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited