AuthServerPluginContext<TContext> class
Context supplied while configuring a server plugin.
Constructors
- AuthServerPluginContext({required AuthStore store, AuthAuthenticationMethodService? authenticationMethods, PasswordHasher? passwordHasher, PasswordPolicy passwordPolicy = const PasswordPolicy(), AuthSessionStrategy sessionStrategy = AuthSessionStrategy.session})
-
Creates plugin configuration context from the host's stores and policies.
const
Properties
- authenticationMethods → AuthAuthenticationMethodService?
-
Authentication-method service shared by the runtime, when available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- passwordHasher → PasswordHasher?
-
Password hasher selected by the host, when available.
final
- passwordPolicy → PasswordPolicy
-
Password policy selected by the host.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionStrategy → AuthSessionStrategy
-
Session strategy selected by the host.
final
- store → AuthStore
-
Typed persistence boundary shared by the runtime.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited