AuthSession class
Session data returned by auth endpoints.
Constructors
- AuthSession({required AuthUser user, required DateTime? expiresAt, AuthSessionStrategy? strategy, String? token})
- Creates a public session response.
Properties
- expiresAt → DateTime?
-
Optional expiry timestamp.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strategy → AuthSessionStrategy?
-
Session strategy used for this session.
final
- token → String?
-
JWT token when using JWT strategy.
final
- user → AuthUser
-
Signed-in user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redacted(
) → AuthSession - Creates a session safe to retain in events and audit records.
-
toJson(
{bool includeToken = false}) → Map< String, dynamic> - Serializes the session payload.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited