AuthSessionCallbackContext<TContext> class
Context passed to session callbacks.
Constructors
-
AuthSessionCallbackContext({required TContext context, required AuthSession session, required Map<
String, dynamic> payload, required AuthUser user, required AuthSessionStrategy strategy, AuthProvider? provider}) - Creates the context supplied to a session callback.
Properties
- context → TContext
-
Framework-specific callback context.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
payload
→ Map<
String, dynamic> -
Mutable payload being customized by the callback.
final
- provider → AuthProvider?
-
Provider used to authenticate the user, when applicable.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → AuthSession
-
Session being serialized for the response.
final
- strategy → AuthSessionStrategy
-
Session strategy that produced the session.
final
- user → AuthUser
-
User represented by the session.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited