AuthSessionCallbackContext<TContext> class
Context passed to session callbacks.
Constructors
-
AuthSessionCallbackContext({required TContext context, required AuthSession session, required Map<
String, dynamic> payload, required AuthUser user, required AuthSessionStrategy strategy, AuthProvider? provider})
Properties
- context → TContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
payload
→ Map<
String, dynamic> -
final
- provider → AuthProvider?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → AuthSession
-
final
- strategy → AuthSessionStrategy
-
final
- user → AuthUser
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited