AuthSessionUpdateResolution class
Result of updating an auth session for a selected strategy.
Constructors
- AuthSessionUpdateResolution({required AuthSession session, Cookie? jwtCookie})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- jwtCookie → Cookie?
-
Issued JWT cookie when strategy is AuthSessionStrategy.jwt.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → AuthSession
-
Updated auth session payload.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited