AuthSignInCallbackContext<TContext> class
Context passed to sign-in callbacks.
Constructors
-
AuthSignInCallbackContext({required TContext context, required AuthUser user, required AuthSessionStrategy strategy, AuthProvider? provider, AuthAccount? account, Map<
String, dynamic> ? profile, AuthCredentials? credentials, bool isNewUser = false, String? callbackUrl}) - Creates the context supplied to a sign-in callback.
Properties
- account → AuthAccount?
-
Linked account used by the provider, when applicable.
final
- callbackUrl → String?
-
Redirect requested by the caller, when one was supplied.
final
- context → TContext
-
Framework-specific callback context.
final
- credentials → AuthCredentials?
-
Credentials supplied by the authentication flow, when applicable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNewUser → bool
-
Whether this sign-in created the user.
final
-
profile
→ Map<
String, dynamic> ? -
Provider profile received during authentication.
final
- provider → AuthProvider?
-
Provider used to authenticate the user, when applicable.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strategy → AuthSessionStrategy
-
Session strategy selected for the sign-in.
final
- user → AuthUser
-
User attempting to sign in.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited