AuthTwoFactorBeginChallengeCommand class
Atomically accepts a trusted device or creates a pending sign-in challenge.
Constructors
- AuthTwoFactorBeginChallengeCommand({required String userId, required AuthTwoFactorChallengeRecord challenge, required DateTime now, String? trustedDeviceTokenHash})
-
Creates the command for beginning or bypassing a sign-in challenge.
const
Properties
- challenge → AuthTwoFactorChallengeRecord
-
Challenge to persist when no trusted device is accepted.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- now → DateTime
-
Time used for trusted-device and challenge expiry checks.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trustedDeviceTokenHash → String?
-
Digest of a presented trusted-device token, when supplied.
final
- userId → String
-
User completing the first authentication step.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited