AuthTwoFactorRegenerateRecoveryCodesCommand class
Atomically verifies TOTP and replaces every recovery-code digest.
Constructors
-
AuthTwoFactorRegenerateRecoveryCodesCommand({required AuthTwoFactorRecord expected, required bool valid, required List<
String> recoveryCodeHashes, required AuthTwoFactorAttemptPolicy policy}) -
Creates the command for replacing recovery-code digests.
const
Properties
- expected → AuthTwoFactorRecord
-
Factor record expected by the atomic update.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- policy → AuthTwoFactorAttemptPolicy
-
Attempt and lockout policy for this command.
final
-
recoveryCodeHashes
→ List<
String> -
Replacement recovery-code digests.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valid → bool
-
Whether the submitted TOTP code was valid.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited