AuthTwoFactorRevokeTrustedDevicesCommand class
Command that revokes every trusted device for a user.
Constructors
- AuthTwoFactorRevokeTrustedDevicesCommand({required String userId, required DateTime now})
-
Creates the command for revoking trusted devices.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited