AuthTwoFactorSignInChallenge class
A short-lived pending sign-in challenge returned to a client.
Constructors
- AuthTwoFactorSignInChallenge({required String token, required DateTime expiresAt})
-
const
Properties
- expiresAt → DateTime
-
Time after which the challenge cannot be completed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
Opaque challenge token that must be returned to the verification route.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited