Backend-owned coordinator for hard user deletion.
- Implementers
Properties
- domain → AuthUserDeletionDomain
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requiredUserDeletionNamespaces
→ Set<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
confirmAndDeleteUser(
{required String userId, required String token, Iterable< AuthUserDeletionPlan> ? plans, DateTime? now}) → Future<bool> -
deleteUser(
String userId, {Iterable< AuthUserDeletionPlan> ? plans}) → Future<bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plansForUser(
AuthUser user) → Future< List< AuthUserDeletionPlan> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited