AuthUserDeletionPreflightException class final
Thrown when a deletion plan set cannot describe one complete transaction.
- Implemented types
Constructors
- AuthUserDeletionPreflightException(String message)
-
Creates an instance of AuthUserDeletionPreflightException.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns a diagnostic string representation.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited