AuthWebAuthnRegistrationOptions class final
Public registration options returned to a WebAuthn client.
Constructors
-
AuthWebAuthnRegistrationOptions({required String challenge, required WebAuthnRelyingParty relyingParty, required String userId, required String userName, required String displayName, required Duration timeout, required String attestation, required List<
String> excludeCredentials, required String userVerification}) -
const
Properties
- attestation → String
-
final
- challenge → String
-
final
- displayName → String
-
final
-
excludeCredentials
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- relyingParty → WebAuthnRelyingParty
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
final
- userId → String
-
final
- userName → String
-
final
- userVerification → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited