redacted method
Creates a provider metadata projection safe for events and audit logs.
OAuth client credentials and other provider implementation details are intentionally not copied into the projection.
Implementation
AuthProvider redacted() => AuthProvider(id: id, name: name, type: type);