FidoMetadataCertificate class final
A certificate trust anchor from a metadata statement.
Properties
-
derBytes
→ List<
int> -
Immutable DER-encoded PKIX certificate bytes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256Fingerprint → String
-
Lowercase hexadecimal SHA-256 fingerprint of derBytes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited