FidoMetadataHttpResponse class final
A bounded response returned by FidoMetadataHttpTransport.
Constructors
Properties
-
bodyBytes
→ List<
int> -
Complete response body, bounded and copied on construction.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Lowercase response headers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status code returned by the transport.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited