Injectable one-hop transport for deterministic tests and custom runtimes.
Constructors
- FidoMetadataHttpTransport.packageHttp({Client? client})
-
Uses
package:httpwithout following redirects automatically.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Releases resources owned by this transport.
-
get(
FidoMetadataHttpRequest request) → Future< FidoMetadataHttpResponse> - Performs one bounded GET request without following redirects.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited