FidoMetadataWebAuthnTrustEvaluator class final
Maps verified WebAuthn attestation provenance to an authenticated MDS entry.
Constructors
- FidoMetadataWebAuthnTrustEvaluator({required FidoMetadataBlob blob, WebAuthnAttestationTrustDecision updateAvailable = WebAuthnAttestationTrustDecision.downgrade, WebAuthnAttestationTrustDecision uncertified = WebAuthnAttestationTrustDecision.reject, FidoMetadataAttestationPathVerifier? verifyAttestationPath})
Properties
- blob → FidoMetadataBlob
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uncertified → WebAuthnAttestationTrustDecision
-
final
- updateAvailable → WebAuthnAttestationTrustDecision
-
final
- verifyAttestationPath → FidoMetadataAttestationPathVerifier?
-
final
Methods
-
asWebAuthnTrustPolicy(
{WebAuthnUnprovenAttestationDecision none = WebAuthnUnprovenAttestationDecision.accept, WebAuthnUnprovenAttestationDecision self = WebAuthnUnprovenAttestationDecision.accept}) → WebAuthnAttestationTrustPolicy -
Creates a WebAuthn policy that retains the caller's choices for unproven
noneand self attestation while routing certificate attestations here. -
call(
WebAuthnAttestationMetadata attestation) → Future< WebAuthnAttestationTrustDecision> - Adapter directly compatible with WebAuthnAttestationTrustPolicy.
-
evaluate(
WebAuthnAttestationMetadata attestation) → Future< FidoMetadataEvaluation> - Evaluates and preserves typed provenance without exposing parser errors.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited