InMemoryAuthVerificationTokenStore class

In-memory token store for development and tests.

Implemented types

Constructors

InMemoryAuthVerificationTokenStore({DateTime clock()?, int maxTokens = 1024})

Properties

hashCode int
The hash code for this object.
no setterinherited
maxTokens int
Maximum number of token digests retained by this local store.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

captureDeletionState() Object
override
consume(String identifier, String token) Future<AuthVerificationToken?>
override
delete(String identifier) Future<void>
override
deleteToken(String identifier, String token) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreDeletionState(Object state) → void
override
save(AuthVerificationToken token) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited