ScimPlugin<TContext> class
final
Typed, server-only SCIM 2.0 provisioning plugin.
The plugin deliberately contributes no Routed auth client plugin. SCIM is consumed by an identity provider using the protocol endpoints directly.
- Implemented types
-
- AuthServerPlugin<
TContext> - AuthEndpointContributor<
TContext> - AuthPersistenceContributor
- AuthServerPlugin<
Constructors
-
ScimPlugin({required AuthScimProvisioningStore store, required AuthScimBearerTokenResolver<
TContext> tokenResolver, AuthScimOptions? options, AuthScimFailureReporter? reportFailure}) - Creates a server-only SCIM provisioning plugin.
Properties
- dataContract → AuthServerPluginDataContract
-
SCIM does not contribute an auth-user persistence contract.
no setteroverride
-
endpoints
→ Iterable<
AuthEndpointDescriptor< TContext> > -
Describes the SCIM protocol endpoints.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable server-plugin identifier.
no setteroverride
- options → AuthScimOptions
-
Bounded SCIM protocol settings.
final
-
persistenceSchemas
→ Iterable<
AuthPersistenceSchema> -
Describes the SCIM persistence schema and atomic operations.
no setteroverride
- reportFailure → AuthScimFailureReporter?
-
Optional internal failure reporter.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store → AuthScimProvisioningStore
-
Application-owned directory persistence boundary.
final
-
tokenResolver
→ AuthScimBearerTokenResolver<
TContext> -
Application-owned bearer-token verification boundary.
final
Methods
-
configure(
AuthServerPluginContext< TContext> context) → void -
Configures the plugin in the server context.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited