SlackProfile class
Slack user profile (OIDC).
See Slack OpenID Connect.
Constructors
- SlackProfile({required String sub, String? email, bool? emailVerified, String? name, String? picture, String? givenName, String? familyName, String? locale, String? slackTeamId, String? slackTeamName, String? slackTeamDomain, String? slackTeamImage})
-
Creates a new SlackProfile with the given fields.
const
-
SlackProfile.fromJson(Map<
String, dynamic> json) -
Creates a SlackProfile from a JSON map returned by the Slack OIDC userinfo endpoint.
factory
Properties
- email → String?
-
User's email address.
final
- emailVerified → bool?
-
Whether the email has been verified.
final
- familyName → String?
-
User's family name.
final
- givenName → String?
-
User's given name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locale → String?
-
User's locale.
final
- name → String?
-
User's full name.
final
- picture → String?
-
URL of the user's profile picture.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slackTeamDomain → String?
-
Slack team/workspace domain.
final
- slackTeamId → String?
-
Slack team/workspace ID.
final
- slackTeamImage → String?
-
Slack team/workspace image.
final
- slackTeamName → String?
-
Slack team/workspace name.
final
- sub → String
-
Subject identifier (user ID).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this profile to a JSON-serializable map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited