UsernamePlugin<TContext> class
final
Opt-in username-first password authentication.
Constructors
- UsernamePlugin({AuthUsernameIdentifierPolicy? identifierPolicy, String authenticationMethod = authUsernameAuthenticationMethod})
Properties
- authenticationMethod → String
-
final
-
authenticationMethodKinds
→ Set<
AuthAuthenticationMethodKind> -
no setteroverride
- authenticationMethodNamespace → String
-
no setteroverride
- authenticationMethodStore → Object
-
no setteroverride
-
clientOperations
→ Iterable<
AuthClientOperationDescriptor> -
no setteroverride
-
endpoints
→ Iterable<
AuthEndpointDescriptor< TContext> > -
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setteroverride
- identifierPolicy → AuthUsernameIdentifierPolicy
-
final
-
persistenceSchemas
→ Iterable<
AuthPersistenceSchema> -
no setteroverride
-
rateLimitOperations
→ Iterable<
AuthRateLimitOperation> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticationMethodsForUser(
String userId) → Future< AuthAuthenticationMethodSnapshot> -
override
-
changeUsername(
{required String userId, required AuthUsernameChangeRequest request, DateTime? now}) → Future< AuthUsernameChangeResult> -
composePluginTopology(
Iterable< AuthServerPlugin< plugins) → voidTContext> > -
override
-
configure(
AuthServerPluginContext< TContext> context) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
{required TContext context, required AuthUsernameRegistrationRequest request, AuthServerPluginSessionControl? sessionControl}) → Future< AuthUsernameAuthenticationResult> -
removeUsername(
{required String userId}) → Future< void> -
signIn(
{required TContext context, required AuthUsernameSignInRequest request, AuthServerPluginSessionControl? sessionControl}) → Future< AuthUsernameAuthenticationResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited