WebAuthnAuthenticator class
Authenticator device stored for a user.
Constructors
Properties
- counter → int
-
Signature counter for replay protection.
final
- createdAt → DateTime?
-
When the authenticator was registered.
final
- credentialId → String
-
Unique credential identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastUsedAt → DateTime?
-
When the authenticator was last used.
final
- name → String?
-
Optional friendly name for the authenticator.
final
- publicKey → String
-
COSE public key bytes (base64 encoded).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transports
→ List<
String> ? -
Supported transports (usb, nfc, ble, internal).
final
- userId → String?
-
Associated user ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited