AuthAdminStoreConformanceFixture class final
Supplies the stores and lifecycle hooks used by an admin conformance case.
Constructors
-
AuthAdminStoreConformanceFixture({required AuthStore coreStore, required AuthAdminStore adminStore, AuthAdminStoreConformanceFaultControl? faultControl, FutureOr<
void> dispose()?}) -
Creates a fixture from the supplied stores and optional hooks.
const
Properties
- adminStore → AuthAdminStore
-
Administrative mutation store under test.
final
- coreStore → AuthStore
-
Core authentication store shared with adminStore.
final
-
dispose
→ FutureOr<
void> Function()? -
Releases resources owned by the fixture.
final
- faultControl → AuthAdminStoreConformanceFaultControl?
-
Optional transaction fault controller.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited