AuthAdminStoreConformanceFixture class final
Constructors
-
AuthAdminStoreConformanceFixture({required AuthStore coreStore, required AuthAdminStore adminStore, AuthAdminStoreConformanceFaultControl? faultControl, FutureOr<
void> dispose()?}) -
const
Properties
- adminStore → AuthAdminStore
-
final
- coreStore → AuthStore
-
final
-
dispose
→ FutureOr<
void> Function()? -
final
- faultControl → AuthAdminStoreConformanceFaultControl?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited