AuthAdminStoreConformanceResult class final
Reports whether an admin-store conformance case passed or was skipped.
Constructors
- AuthAdminStoreConformanceResult.passed()
-
Creates a successful result.
const
- AuthAdminStoreConformanceResult.skipped(String? skippedReason)
-
Creates a skipped result with
skippedReason.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSkipped → bool
-
Whether this result represents a skipped case.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skippedReason → String?
-
Explanation for a skipped case, or
nullwhen the case passed.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited