cases property
List<AuthAnonymousStoreConformanceCase>
get
cases
The isolated cases exposed by this suite.
Implementation
List<AuthAnonymousStoreConformanceCase> get cases => [
_case(
'create_replay',
'Creation is atomic and replay-safe.',
_createReplay,
),
_case(
'create_contention',
'Concurrent creation commits exactly one identity.',
_createContention,
),
_case(
'create_rollback',
'Creation rolls back a fault after its user write.',
_createRollback,
),
_case(
'delete_contention',
'Authenticated deletion commits once under contention.',
_deleteContention,
),
_case(
'delete_rollback',
'Deletion restores the anonymous identity after a transaction fault.',
_deleteRollback,
),
_case(
'hard_delete_scrubs_create_replay',
'Generic hard deletion scrubs anonymous creation replay data.',
_hardDeleteScrubsCreateReplay,
),
_case(
'upgrade_replay',
'Upgrade finalization preserves its target and replays safely.',
_upgradeReplay,
),
_case(
'upgrade_rollback',
'Upgrade finalization restores its source after a transaction fault.',
_upgradeRollback,
),
_case(
'upgrade_target_binding',
'Upgrade replay receipts cannot be rebound to another target.',
_upgradeTargetBinding,
),
];