AuthApiKeyStoreConformanceFixture class final

Constructors

AuthApiKeyStoreConformanceFixture({required AuthApiKeyStore store, required AuthApiKeyStoreConformanceFaultController faults, FutureOr<void> dispose()?})
const

Properties

dispose FutureOr<void> Function()?
final
faults AuthApiKeyStoreConformanceFaultController
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store AuthApiKeyStore
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited