AuthEmailBackendConformanceFixture class final
Fresh adapter fixture used by each email-auth conformance case.
Constructors
- AuthEmailBackendConformanceFixture({required AuthMagicLinkBackend magicLinks, required AuthEmailOtpBackend emailOtps, required AuthUserStore users})
-
Creates a fixture from the email capabilities and user store.
const
Properties
- emailOtps → AuthEmailOtpBackend
-
Email OTP backend under test.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- magicLinks → AuthMagicLinkBackend
-
Magic-link backend under test.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- users → AuthUserStore
-
User store shared by the backend capabilities.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited