AuthEmailBackendConformanceFixture class final

Fresh adapter fixture used by each email-auth conformance case.

Constructors

AuthEmailBackendConformanceFixture({required AuthMagicLinkBackend magicLinks, required AuthEmailOtpBackend emailOtps, required AuthUserStore users})
const

Properties

emailOtps AuthEmailOtpBackend
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users AuthUserStore
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited