AuthOAuthProviderFixture class final
OAuth/OIDC provider metadata with deterministic test endpoints and profile.
Constructors
-
AuthOAuthProviderFixture({String providerId = 'fixture-oauth', Map<
String, dynamic> profile = const <String, dynamic>{'sub' : 'fixture-account', 'email' : 'fixture@example.test', 'name' : 'Fixture User'}, AuthProviderType type = AuthProviderType.oauth}) -
Creates a provider fixture hosted below
https://provider.example.test.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
profile
→ Map<
String, dynamic> -
Claims returned by the fixture's user-information endpoint.
final
-
provider
↔ OAuthProvider<
Map< String, dynamic> > -
Real OAuth provider configured by the fixture.
latefinal
- providerId → String
-
Stable provider identifier used by the fixture.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AuthProviderType
-
OAuth flow type exercised by the fixture.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tokenResponse(
{String accessToken = 'fixture-access'}) → Map< String, dynamic> - Successful token endpoint payload.
-
toString(
) → String -
A string representation of this object.
inherited
-
userInfoResponse(
) → Map< String, dynamic> - Successful userinfo endpoint payload.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited