AuthPhoneNumberBackendConformanceFixture class final

Constructors

AuthPhoneNumberBackendConformanceFixture({required AuthStore store, required AuthPhoneNumberBackend backend, required AuthPhoneNumberBackendConformanceFaultController faults, required FutureOr<bool> hardDeleteUser(String userId), FutureOr<void> dispose()?})
const

Properties

backend AuthPhoneNumberBackend
final
dispose FutureOr<void> Function()?
final
faults AuthPhoneNumberBackendConformanceFaultController
final
hardDeleteUser FutureOr<bool> Function(String userId)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store AuthStore
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited