AuthPluginConformanceResult class final

The result of running one plugin-composition conformance case.

Constructors

AuthPluginConformanceResult.passed()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isPassed bool
Whether the composed plugin topology satisfied this case.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited