AuthScimConnectionStoreConformanceFixture class final

Supplies the connection store and lifecycle hooks used by a case.

Constructors

AuthScimConnectionStoreConformanceFixture({required AuthScimConnectionStore store, FutureOr<void> dispose()?})
Creates a fixture from the connection store and optional disposer.
const

Properties

dispose FutureOr<void> Function()?
Releases resources owned by the fixture.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store AuthScimConnectionStore
Managed-SCIM connection store under test.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited