AuthScimConnectionStoreConformanceSuite class final
Reusable contract for durable managed-SCIM connection adapters.
Constructors
- AuthScimConnectionStoreConformanceSuite(AuthScimConnectionStoreConformanceFactory createFixture)
-
Creates a suite backed by
createFixture.
Properties
-
cases
→ List<
AuthScimConnectionStoreConformanceCase> -
The isolated cases exposed by this suite.
no setter
- createFixture → AuthScimConnectionStoreConformanceFactory
-
Creates the isolated fixture used by each case.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited