AuthScimConnectionStoreConformanceSuite class final

Reusable contract for durable managed-SCIM connection adapters.

Properties

cases List<AuthScimConnectionStoreConformanceCase>
no setter
createFixture AuthScimConnectionStoreConformanceFactory
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited