AuthStoreConformanceFixture class final
An isolated adapter instance and its optional cleanup callback.
Constructors
-
AuthStoreConformanceFixture({required AuthStore store, FutureOr<
void> dispose()?}) -
Creates a fixture around
store.const
Properties
-
dispose
→ FutureOr<
void> Function()? -
Releases database handles or removes the fixture namespace.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store → AuthStore
-
The adapter under test.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited