AuthTestHttpRequest class final
A fully buffered request captured by AuthTestHttpClient.
Constructors
Properties
- body → String
-
UTF-8 request body.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Request headers.
final
- method → String
-
HTTP method exactly as sent by the auth client.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri
-
Absolute request URI.
final
Methods
-
jsonObject(
) → Map< String, dynamic> - Decodes body as a JSON object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited