AuthTestHttpResponse class final

A framework-neutral response returned by an auth test responder.

Constructors

AuthTestHttpResponse({required int statusCode, required String body, Map<String, String> headers = const <String, String>{}})
Creates a raw response.
const
AuthTestHttpResponse.error(String code, {int statusCode = 400, String? message, Map<String, String> headers = const <String, String>{}})
Creates the bounded public error shape consumed by AuthClientTransport.
factory
AuthTestHttpResponse.json(Object? value, {int statusCode = 200, Map<String, String> headers = const <String, String>{}})
Creates a JSON response.
factory

Properties

body String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited