AuthTestSessionControl class final
Session control with deterministic timestamps for portable plugin tests.
- Implemented types
Constructors
- AuthTestSessionControl({required DateTime clock(), AuthSessionStrategy strategy = AuthSessionStrategy.session, Duration maximumAge = const Duration(hours: 1), String? currentSessionId = 'fixture-session'})
-
Creates a session control using
clockfor issued expiration times.
Properties
-
authenticationMethods
→ List<
String> -
Authentication methods issued in order.
final
- currentSessionId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumAge → Duration
-
Default session lifetime for completeAuthentication.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessions
→ List<
AuthSession> -
Sessions issued in order.
final
- signedOut ↔ bool
-
Whether signOut was invoked.
getter/setter pair
- strategy → AuthSessionStrategy
-
final
Methods
-
completeAuthentication(
AuthEndpointAuthenticationIntent intent) → AuthSession - Completes one endpoint authentication intent for portable fixture tests.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signOut(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited