AuthUsernameStoreConformanceFixture class final

Isolated adapter fixture for the public username transaction verifier.

Constructors

AuthUsernameStoreConformanceFixture({required AuthStore store, FutureOr<void> armFault(AuthUsernameFaultPoint point)?})
const

Properties

armFault FutureOr<void> Function(AuthUsernameFaultPoint point)?
Arms one deterministic failure inside the adapter's next transaction.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store AuthStore
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited